/*
	EGX system - by Enigx
	
	CallArtillery.sqf
	

******************************************************************************************************************
// nul = [alias_target,smokes_rounds,flares_rounds,expl_rounds,smoke_radius,flares_radius,expl_radius,smokes_freq,flares_freq,expl_freq] execvm "EGX_system\functions\ALartillery\alias_artillery.sqf";
// Tutorial: https://www.youtube.com/user/aliascartoons

* Script MP and SP compatible
alias_target	- object name, array of markers and/or objects, or player in SP or MP
smokes_rounds	- integer
flares_rounds	- integer
expl_rounds		- integer

smoke_radius	- number/meters, area where smokes will be spawned when applicable
flares_radius	- number/meters
expl_radius		- number/meters

smokes_freq		- number/seconds between shots/spawn
flares_freq		- number/seconds between shots/spawn
expl_freq		- number/seconds between shots/spawn

=============== alias_target VALUES can be on of the following
"mp_alias" 			- if is a scenario where you want explosions to follow one of the alive players
"area_alias" 		- area defined by a marker called area_alias with radius of 200m where smokes and/or flares and/or explosions will be spawned
["marke_1",obj_1]	- array of markers or objects where you want to spawn explosions, insert as many as you want but make sure markers and objects exists on map

======= Example Usage ====================
> Smokes only
	- 20 rounds, in area with center in a marker called area_alias at an interval of 0.1 seconds
		nul = ["area_alias",20,0,0,300,0,0,0.1,0,0] execvm "EGX_system\functions\ALartillery\alias_artillery.sqf";
	- 20 rounds around a random player at an interval of 5 seconds
		nul = ["mp_alias",20,0,0,0,0,0,5,0,0] execvm "EGX_system\functions\ALartillery\alias_artillery.sqf";
	- 20 rounds in a random location from array at an interval of 1 seconds
		nul = [["t1","t2","t3",v1,v2],20,0,0,0,0,0,1,0,0] execvm "ALartillery\alias_artillery.sqf";

> Flares only
	- 30 rounds, in area with center in a marker called area_alias at an interval of 1 seconds
		nul = ["area_alias",0,30,0,0,300,0,0,1,0] execvm "EGX_system\functions\ALartillery\alias_artillery.sqf";
	- 10 rounds around a random player at an interval of 1 seconds
		nul = ["mp_alias",0,10,0,0,0,0,0,1,0] execvm "EGX_system\functions\ALartillery\alias_artillery.sqf";
	- 30 rounds in a random location from array at an interval of 1 seconds
		nul = [["t1","t2","t3",v1,v2],0,30,0,0,0,0,0,1,0] execvm "EGX_system\functions\ALartillery\alias_artillery.sqf";

> Explosive shells only 
	- 10 rounds, in area with center in a marker called area_alias at an interval of 2 seconds
		nul = ["area_alias",0,0,10,0,0,300,0,0,2] execvm "EGX_system\functions\ALartillery\alias_artillery.sqf";
	- 10 rounds around a random player at an interval of 2 seconds
		nul = ["mp_alias",0,0,10,0,0,0,0,0,2] execvm "EGX_system\functions\ALartillery\alias_artillery.sqf";
	- 30 rounds in a random location from array at an interval of 2 seconds
		nul = [["t1","t2","t3",v1,v2],0,0,30,0,0,0,0,0,2] execvm "ALartillery\alias_artillery.sqf";

> All (smokes, flares and explosions)
	- in area defined by marker called area_alias will be spawned 30 smokes, 20 flares, 50 explosions in a radius of 300, 250 and 200, and different intervals between rounds
		nul = ["area_alias",30,25,50,300,250,200,2,10,1] execvm "EGX_system\functions\ALartillery\alias_artillery.sqf";

******************************************************************************************************************	
*/


_TypeShoot = _this select 0;

// Waiting time (sec) for the arrival of artillery shells
_tiriTime = 10; 		// ====== CHANGE PARAMETER IF NECESSARY

    private _dialogValues = ["Request artillery",[
				["SLIDER","Number of shells on the target",[1,30,0],20],
        ["SLIDER","Radius of the attack area",[20,200,0],100],
        ["SLIDER","Time between shells (seconds)",[0.5,5,1],2],
        ["CHECKBOX","Hide messages (e.g. to use it on blufor)",[],false]  
     ]] call CDS_fnc_createDialog;
    if (_dialogValues isEqualTo []) exitWith {};
    _dialogValues params ["_gunsRound","_gunsRadius","_gunsFreq","_toBlufor"];

null = [20,1] execVM "EGX_system\functions\MarkPlayersPosition.sqf"; // Display players position for 20 seconds with refresh every 1 second ====== MODIFY OR DELETE IF NECESSARY		

createMarker ["area_alias",[0,0,0]];
"area_alias" setMarkerShape "RECTANGLE";
"area_alias" setMarkerSize [10, 10];
"area_alias" setMarkerAlpha 0;

sleep 0.1;
openMap true;
mapclick = true;
hint "Click on the position on the map where to call the artillery shells";
onMapSingleClick """area_alias"" setMarkerPos _pos;mapclick = false;
onMapSingleClick ''; true;";
waitUntil {!mapClick};
createMarkerLocal ["targArtil", getMarkerPos "area_alias"];
"targArtil" setMarkerTypeLocal "hd_objective";
"targArtil" setMarkerColorLocal "ColorRed";
sleep 1;
openMap false;

if (_TypeShoot==1) then
	{
	if (!_toBlufor) then {["Warning! Smoke screen with incoming artillery shells!"] remoteExec ["hint",0,false];} else {hint "Smoke screen coming up (no text shown to players)";};
	sleep _tiriTime;
	[["area_alias",_gunsRound,0,0,_gunsRadius,0,0,_gunsFreq,0,0], "EGX_system\functions\ALartillery\alias_artillery.sqf"] remoteExec ["execVM",2,false];
	sleep (_gunsRound*_gunsFreq*2);
	deleteMarker "area_alias";
	deleteMarkerLocal "targArtil";
	} 
	else
	{
	if (_TypeShoot==2) then
			{
			if (!_toBlufor) then {["Warning! Lighting with flares with incoming artillery shells!"] remoteExec ["hint",0,false];} else {hint "Flares coming up (no text shown to players)";};
			sleep _tiriTime;
			[["area_alias",0,_gunsRound,0,0,_gunsRadius,0,0,_gunsFreq,0], "EGX_system\functions\ALartillery\alias_artillery.sqf"] remoteExec ["execVM",2,false];
			sleep (_gunsRound*_gunsFreq*2);
			deleteMarker "area_alias";
			deleteMarkerLocal "targArtil"; 
			}
			else
			{
			if (!_toBlufor) then {["Warning! Bombardment with incoming artillery!"] remoteExec ["hint",0,false];} else {hint "Incoming artillery fire (no text shown to players)";};
			sleep _tiriTime;
			[["area_alias",0,0,_gunsRound,0,0,_gunsRadius,0,0,_gunsFreq], "EGX_system\functions\ALartillery\alias_artillery.sqf"] remoteExec ["execVM",2,false];
			sleep (_gunsRound*_gunsFreq*2);
			deleteMarker "area_alias";
			deleteMarkerLocal "targArtil";
			};		
	};

