/*-----------------------------------------------------------------------------------------------//
Authors: Sceptre
Sets the new selected/default value and the available values of a control.

Parameters:
0: Control index <SCALAR>
1: New selected/default value <BOOL,SCALAR,STRING>

Returns:
Nothing
//-----------------------------------------------------------------------------------------------*/
disableSerialization;
params [["_ctrlIndex",0,[0]],["_ctrlDefault",0,[true,0,""]],["_ctrlValues",[],[[]]]];

private _ctrl = findDisplay 12700 displayCtrl (CDS_controlsInfo # _ctrlIndex) # 0;

switch ((CDS_controlsInfo # _ctrlIndex) # 2) do {
	case "CHECKBOX" : {
		if !(_ctrlDefault isEqualType true) exitWith {systemChat format ["Control %1 : Invalid default CHECKBOX value",_ctrlIndex];};
		(CDS_controlsInfo select _ctrlIndex) set [4,_ctrlValues];

		_ctrl cbSetChecked _ctrlDefault;
	};
	case "EDITBOX" : {
		if !(_ctrlDefault isEqualType "") exitWith {systemChat format ["Control %1 : Invalid default EDITBOX value",_ctrlIndex];};
		(CDS_controlsInfo select _ctrlIndex) set [4,_ctrlValues];

		_ctrl ctrlSetText _ctrlDefault;
	};
	case "SLIDER" : {
		if !(_ctrlDefault isEqualType 0) exitWith {systemChat format ["Control %1 : Invalid default SLIDER value",_ctrlIndex];};
		if (count _ctrlValues != 3 && {_x isEqualType 0} count _ctrlValues != 3) exitWith {systemChat format ["Control %1 : Invalid SLIDER range values",_ctrlIndex];};
		(CDS_controlsInfo select _ctrlIndex) set [4,_ctrlValues];

		private _fixedValue = _ctrlDefault toFixed (_ctrlValues # 2);
		private _ctrlAux = findDisplay 12700 displayCtrl (CDS_controlsInfo # _ctrlIndex) # 8;
		_ctrlAux ctrlSetText _fixedValue;
		_ctrl sliderSetRange [_ctrlValues # 0,_ctrlValues # 1];
		_ctrl sliderSetPosition _ctrlDefault;
		_ctrl ctrlSetTooltip _fixedValue;
	};
	case "COMBOBOX" : {
		if !(_ctrlDefault isEqualType 0) exitWith {systemChat format ["Control %1 : Invalid default COMBOBOX value",_ctrlIndex];};
		(CDS_controlsInfo select _ctrlIndex) set [4,_ctrlValues];

		lbClear _ctrl;
		{
			_ctrl lbAdd _x;
			false
		} count _ctrlValues;
		_ctrl lbSetCurSel _ctrlDefault;
	};
	default {};
};
